@@ -2,13 +2,10 @@
 # this repository contains the full copyright notices and license terms.
 from trytond.pool import PoolMeta
 from trytond.model import fields
+from trytond.tools import lstrip_wildcard
 
 
-__all__ = ['Party', 'PartyReplace']
-
-
-class Party:
-    __metaclass__ = PoolMeta
+class Party(metaclass=PoolMeta):
     __name__ = 'party.party'
     bank_accounts = fields.Many2Many('bank.account-party.party', 'owner',
         'account', 'Bank Accounts')
@@ -20,19 +17,22 @@ class Party:
             bool_op = 'AND'
         else:
             bool_op = 'OR'
+        code_value = clause[2]
+        if clause[1].endswith('like'):
+            code_value = lstrip_wildcard(clause[2])
         return [bool_op,
             domain,
-            ('bank_accounts',) + tuple(clause[1:]),
+            ('bank_accounts.numbers.rec_name',
+                clause[1], code_value) + tuple(clause[3:]),
             ]
 
 
-class PartyReplace:
-    __metaclass__ = PoolMeta
+class Replace(metaclass=PoolMeta):
     __name__ = 'party.replace'
 
     @classmethod
     def fields_to_replace(cls):
-        return super(PartyReplace, cls).fields_to_replace() + [
+        return super().fields_to_replace() + [
             ('bank', 'party'),
             ('bank.account-party.party', 'owner'),
             ]
